Carefully evaluate which sites will be allowed to make cross-domain
calls.

Consider network topology and any authentication mechanisms
that will be affected by the configuration or implementation of the
cross-domain policy.